# rointe-sdk

Rointeconnect SDK is a python library for the Rointe HomeAssistant integration.

## Changelog

- v1.0.8

  - When setting hvac mode to auto, set the temperature to Comfort.
  - Fix authentication refresh issue.

- v1.0.7
  - Minor fix.
